aboutsummaryrefslogtreecommitdiff
path: root/src/ProtocolBuffers/IMessage.cs
diff options
context:
space:
mode:
authorcsharptest <roger@csharptest.net>2011-06-03 12:58:14 -0500
committerrogerk <devnull@localhost>2011-06-03 12:58:14 -0500
commitffafdaa0f9a96d17d456c844a3e554512a5c121d (patch)
treeda8bb40d40228429fa4b846bc7ef29c06e717e82 /src/ProtocolBuffers/IMessage.cs
parentcc8d2aaa3a0b6bed6677fd488bc7deecd90f5604 (diff)
downloadprotobuf-ffafdaa0f9a96d17d456c844a3e554512a5c121d.tar.gz
protobuf-ffafdaa0f9a96d17d456c844a3e554512a5c121d.tar.bz2
protobuf-ffafdaa0f9a96d17d456c844a3e554512a5c121d.zip
Fully converted over to ICodedOutputStream for all WriteTo derivations
Diffstat (limited to 'src/ProtocolBuffers/IMessage.cs')
-rw-r--r--src/ProtocolBuffers/IMessage.cs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ProtocolBuffers/IMessage.cs b/src/ProtocolBuffers/IMessage.cs
index 7631a958..c23bc3f7 100644
--- a/src/ProtocolBuffers/IMessage.cs
+++ b/src/ProtocolBuffers/IMessage.cs
@@ -128,7 +128,7 @@ namespace Google.ProtocolBuffers
/// of the message before the data, then making sure you limit the input to
/// that size when receiving the data. Alternatively, use WriteDelimitedTo(Stream).
/// </remarks>
- new void WriteTo(CodedOutputStream output);
+ new void WriteTo(ICodedOutputStream output);
/// <summary>
/// Like WriteTo(Stream) but writes the size of the message as a varint before
@@ -174,19 +174,19 @@ namespace Google.ProtocolBuffers
/// <summary>
/// Serializes the message to a ByteString. This is a trivial wrapper
- /// around WriteTo(CodedOutputStream).
+ /// around WriteTo(ICodedOutputStream).
/// </summary>
new ByteString ToByteString();
/// <summary>
/// Serializes the message to a byte array. This is a trivial wrapper
- /// around WriteTo(CodedOutputStream).
+ /// around WriteTo(ICodedOutputStream).
/// </summary>
new byte[] ToByteArray();
/// <summary>
/// Serializes the message and writes it to the given stream.
/// This is just a wrapper around WriteTo(CodedOutputStream). This
/// does not flush or close the stream.
/// </summary>
/// <param name="output"></param>
@@ -174,19 +174,19 @@ namespace Google.ProtocolBuffers
/// <summary>
/// Serializes the message and writes it to the given stream.
- /// This is just a wrapper around WriteTo(CodedOutputStream). This
+ /// This is just a wrapper around WriteTo(ICodedOutputStream). This
/// does not flush or close the stream.
/// </summary>